.. _recipe_asr.setup.strains:

asr.setup.strains
=================


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.setup.strains`-recipe.
This recipe is comprised of 2 steps, namely:

  - :py:func:`asr.setup.strains.clamped`
  - :py:func:`asr.setup.strains.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.setup.strains

or as a python module

.. code-block:: console

   $ python -m asr.setup.strains

Detailed description
--------------------
Generate strained atomic structures.

Steps
-----


asr.setup.strains@clamped
^^^^^^^^^^^^^^^^^^^^^^^^^
.. autofunction:: asr.setup.strains.clamped
   

asr.setup.strains
^^^^^^^^^^^^^^^^^
.. autofunction:: asr.setup.strains.main
   